{ pkgs, ... }:

let
  network = import ./network.nix;
  domain = "media.giugl.io";
in {
  disabledModules = [ "services/misc/jellyfin.nix" ];
  imports = [ ./modules/jellyfin.nix ];

  services = {
    jellyfin = {
      enable = true;
      group = "media";
      package = pkgs.unstable.jellyfin;
    };

    nginx.virtualHosts.${domain} = {
      forceSSL = true;
      enableACME = true;
      locations."/" = {
        proxyPass = "http://localhost:8096";
        extraConfig = ''
          # Disable buffering when the nginx proxy gets very resource heavy upon streaming
          proxy_buffering off;

          allow 10.0.0.0/24;
          allow 10.3.0.0/24;
          deny all;
        '';
      };
      
      locations."/socket" = {
        proxyPass = "http://localhost:8096";
        proxyWebsockets = true;
        extraConfig = ''
          # Disable buffering when the nginx proxy gets very resource heavy upon streaming
          proxy_buffering off;

          allow 10.0.0.0/24;
          allow 10.3.0.0/24;
          deny all;
        '';
      };
    };
  };

  networking.extraHosts = ''
    ${network.architect-lan} ${domain}
    ${network.architect-wg} ${domain}
  '';

  users.groups.media.members = [ "jellyfin" ];
  users.groups.video.members = [ "jellyfin" ];
  users.groups.render.members = [ "jellyfin" ];

  fileSystems."/tmp/jellyfin" = {
    device = "none";
    fsType = "tmpfs";
    options = [ "defaults" "size=20G" "uid=jellyfin" ];
  };
}
